
#ifndef RS232_H
#define RS232_H

#if __cplusplus
extern "C" {
#endif

#define COM1    0
#define COM2    1               /* serial ports */

#define PNO     0               /* no parity    */
#define PEVEN   1               /* even parity */
#define PODD    2               /* odd parity */

typedef unsigned char uchar ;
typedef struct MOD_STATUS {    /* Flags aus Modem-Status */
   unsigned CTS : 1 ;          /* Clear To Send  (D25, PIN #5) */
   unsigned DSR : 1 ;          /* Data Set Ready (D25, PIN #6) */
   unsigned RING: 1 ;          /* Ring Indicator (D25, PIN #22) */
   unsigned CD  : 1 ;          /* Carrier Detect                */
} ModemStatus_t ;


int rs_init (unsigned port, unsigned baud, unsigned data_bits,
	     unsigned stop_bits, unsigned parity) ;
/*  port ;             / port to init /
 *  baud ;             / Baudrate to use /
 *  data_bits ;        / Number of databits /
 *  stop_bits ;        / Number of stopbits /
 *  parity ;           / Parity to use /
 */

/****************************************************************************
 *                                                                          *
 *          Start driver by enabling interrupt used by seriell port         *
 *            set parameters as used by interrupt service routine           *                                                                          *
 *                                                                          *
 ****************************************************************************/
void rs_start(unsigned port, uchar *rx_buf, unsigned rx_size,
                             uchar *tx_buf, unsigned tx_size) ;
/*  rx_buf, rx_size : Receive Buffer Address and Size
 *  tx_buf, tx_size : Send Buffer Address and size, use NULL and 0 if
 *                    no interrupt driven output wanted
 */

/****************************************************************************
 *                                                                          *
 *             Stop driver by disabling interrupt used by seriell port      *
 *                                                                          *
 ****************************************************************************/
int rs_stop(unsigned port) ;


/****************************************************************************
 *                                                                          *
 *                 Send a single character to seriell port                  *
 *                                                                          *
 ****************************************************************************/
void rs_outchar (unsigned port, uchar ch) ;


/****************************************************************************
 *                                                                          *
 *                   Get next character stored in Buffer                    *
 *                                                                          *
 *     Return value: char if character available, -1 if nothing available   *
 *                                                                          *
 ****************************************************************************/
int rs_inchar(unsigned port) ;


/****************************************************************************
 *                                                                          *
 *            Send a whole string (terminated by NULL-Charakter)            *
 *                                                                          *
 ****************************************************************************/
void rs_sendline(unsigned port, char *line) ;


/****************************************************************************
 *                                                                          *
 *            Send a block of data by block and count                       *
 *                                                                          *
 ****************************************************************************/
void rs_sendblock(unsigned port, void *block, unsigned bsize) ;


/****************************************************************************
 *                                                                          *
 *           Return number of bytes in transmission spool buffer            *
 *                                                                          *
 ****************************************************************************/
int rs_remaining(unsigned port) ;


/****************************************************************************
 *                                                                          *
 *           Return number of bytes availble in receive buffer              *
 *                                                                          *
 ****************************************************************************/
int rs_status(unsigned port) ;


/****************************************************************************
 *                                                                          *
 *           Return actual modem Status                                     *
 *                                                                          *
 ****************************************************************************/
ModemStatus_t rs_modemstatus(unsigned port) ;

/****************************************************************************
 *                                                                          *
 *           Set/Reset  RTS / DTR Lines                                     *
 *                                                                          *
 ****************************************************************************/
void rs_setdtr(unsigned port, int v);  /* v=0 -> low pegel, v!=0 -> high */
void rs_setrts(unsigned port, int v);  /* v=0 -> low pegel, v!=0 -> high */



#if __cplusplus
}
#endif

#endif /* RS232H */
